@@ -1,10 +1,10 @@
 ##----------------------------------------------------------------------------
 ## PO Files Manipulation - ~/lib/Text/PO.pm
-## Version v0.1.0
+## Version v0.1.1
 ## Copyright(c) 2018 DEGUEST Pte. Ltd.
 ## Author: Jacques Deguest <jack@deguest.jp>
 ## Created 2018/06/21
-## Modified 2018/06/21
+## Modified 2021/07/27
 ## All rights reserved
 ## 
 ## This program is free software; you can redistribute  it  and/or  modify  it
@@ -26,7 +26,7 @@ BEGIN
     use Nice::Try;
     use Scalar::Util;
     use Text::PO::Element;
-    our $VERSION = 'v0.1.0';
+    our $VERSION = 'v0.1.1';
 };
 
 INIT
@@ -1348,7 +1348,7 @@ Text::PO - Read and write PO files
 
 =head1 VERSION
 
-    v0.1.0
+    v0.1.1
 
 =head1 DESCRIPTION
 
@@ -1358,7 +1358,7 @@ L<Text::PO::MO> reads and writes C<.mo> (machine object) binary files.
 
 Thus, with those modules, you do not need to install C<msgfmt>, C<msginit> of GNU. It is better if you have them though.
 
-Also, this distribution provides a way to export the C<po> files in json format to be used from within JavaScript and a JavaScript class to load and use those files is also provided along with some command line scripts. See the C<share> folder alone with its own test units.
+Also, this distribution provides a way to export the C<po> files in json format to be used from within JavaScript and a JavaScript class to load and use those files is also provided along with some command line scripts. See the C<share> folder along with its own test units.
 
 Also, there is a script in C<scripts> that can be used to transcode C<.po> or C<mo> files into json format and vice versa.
 
@@ -1368,7 +1368,7 @@ Also, there is a script in C<scripts> that can be used to transcode C<.po> or C<
 
 Create a new Text::PO object acting as an accessor.
 
-One object should be created per po file, because it stores internally the po data for that file in the C<Text::PO> object instantiated.
+One object should be created per po file, because it stores internally the po data for that file in the L<Text::PO> object instantiated.
 
 Returns the object.
 
@@ -1376,7 +1376,7 @@ Returns the object.
 
 =head2 add_element
 
-Given either a C<Text::PO::Element> object, or an hash ref with keys like C<msgid> and C<msgstr>, or given a C<msgid> followed by an optional hash ref, L</add_element> will add this to the stack of elements.
+Given either a L<Text::PO::Element> object, or an hash ref with keys like C<msgid> and C<msgstr>, or given a C<msgid> followed by an optional hash ref, L</add_element> will add this to the stack of elements.
 
 It returns the newly created element if it did not already exist, or the existing one found. Thus if you try to add an element data that already exists, this will prevent it and return the existing element object found.
 
@@ -1454,11 +1454,11 @@ Thus, one could create a perl script, read a po file, then redirect the output o
 
     ./po_script.pl en_GB.po > new_en_GB.po
 
-It returns the C<Text::PO> object used.
+It returns the L<Text::PO> object used.
 
 =head2 elements
 
-Returns the array reference of all the C<Text::PO::Element> objects
+Returns the array reference of all the L<Text::PO::Element> objects
 
 =head2 encoding
 
@@ -1466,7 +1466,7 @@ Sets or gets the character set encoding for the GNU PO file. Typically this shou
 
 =head2 exists
 
-Given a C<Text::PO::Element> object, it will check if this object exists in its current stack.
+Given a L<Text::PO::Element> object, it will check if this object exists in its current stack.
 
 It returns true of false accordingly.
 
@@ -1696,7 +1696,7 @@ Jacques Deguest E<lt>F<jack@deguest.jp>E<gt>
 
 =head1 SEE ALSO
 
-L<Text::PO::Element>, L<Text::PO::MO>
+L<Text::PO::Element>, L<Text::PO::MO>, L<Text::PO::Gettext>
 
 L<https://www.gnu.org/software/gettext/manual/html_node/PO-Files.html>,
 
